.. _swh-loader-svn:

Software Heritage - Subversion loader
=====================================

Loader for `Subversion <https://subversion.apache.org/>`_ repositories.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
